CText class

Inheritance
Implementers

Constructors

CText({CFont font = CFont.tss16, CRotation rotation = CRotation.rotation_0, required int textX, required int textY, required String content, bool? bold, bool? underline, bool? mag})

Properties

appendClause List<CommandClause>
finalinherited
bold bool?
no setter
content String
no setter
font CFont
no setter
hashCode int
The hash code for this object.
no setterinherited
mag bool?
no setter
prependClause List<CommandClause>
finalinherited
rotation CRotation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textX int
no setter
textY int
no setter
underline bool?
no setter

Methods

append(Arg<String> arg) CText
inherited
clause() → CommandClause
override
clauses() List<CommandClause>
inherited
clear() → void
inherited
override
newline() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepend(Arg<String> arg) CText
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited