CTextCanvas class

Inheritance

Constructors

CTextCanvas({required List<int> imageBytes, required int textX, required int textY, bool compress = false})

Properties

appendClause List<CommandClause>
finalinherited
bold bool?
no setterinherited
compress bool
final
content String
no setterinherited
font CFont
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
imageBytes List<int>
final
mag bool?
no setterinherited
prependClause List<CommandClause>
finalinherited
rotation CRotation
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textX int
no setterinherited
textY int
no setterinherited
underline bool?
no setterinherited

Methods

append(Arg<String> arg) CText
inherited
clause() → CommandClause
override
clauses() List<CommandClause>
inherited
clear() → void
inherited
override
newline() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepend(Arg<String> arg) CText
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateImageBytes({required String content, CFont font = CFont.tss16, CRotation rotation = CRotation.rotation_0, bool? bold, int alpha = 255, Uint8List? familyBytes}) Future<List<int>>